@@ -162,8 +162,12 @@ class DataMediator:
         are additional options. A custom sampling method callback may also be passed,
         which is called instead on split & holdout dataframes.
         """
-        largeSplit = max([self.experimental, self.control], key=len)
-        smallSplit = min([self.experimental, self.control], key=len)
+        largeSplit = max(
+            [self.experimental.copy(deep=True), self.control.copy(deep=True)], key=len
+        )
+        smallSplit = min(
+            [self.experimental.copy(deep=True), self.control.copy(deep=True)], key=len
+        )
 
         if hasattr(self, "verbose"):
             print(f"Unbalanced classes— {False if largeSplit == smallSplit else True}")
